==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/WebTabDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Description } from "./Description";
import { markType } from "./type";
/**
 * @hidden
 */
var WebTabDescription = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebTabDescription, _super);
    function WebTabDescription() {
        var _this = _super.call(this) || this;
        _this.j = null;
        _this.g = false;
        _this.f = false;
        return _this;
    }
    WebTabDescription.prototype.get_type = function () {
        return "WebTab";
    };
    Object.defineProperty(WebTabDescription.prototype, "type", {
        get: function () {
            return this.get_type();
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WebTabDescription.prototype, "panel", {
        get: function () {
            return this.j;
        },
        set: function (a) {
            this.j = a;
            this.e("Panel");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WebTabDescription.prototype, "selected", {
        get: function () {
            return this.g;
        },
        set: function (a) {
            this.g = a;
            this.e("Selected");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WebTabDescription.prototype, "disabled", {
        get: function () {
            return this.f;
        },
        set: function (a) {
            this.f = a;
            this.e("Disabled");
        },
        enumerable: false,
        configurable: true
    });
    WebTabDescription.$t = markType(WebTabDescription, 'WebTabDescription', Description.$);
    return WebTabDescription;
}(Description));
export { WebTabDescription };

==> igniteui-react-core-19.0.0.tgz: package/esm5/lib/WebTabDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Description } from "./Description";
import { markType } from "./type";
/**
 * @hidden
 */
var WebTabDescription = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebTabDescription, _super);
    function WebTabDescription() {
        var _this = _super.call(this) || this;
        _this.l = null;
        _this.i = false;
        _this.h = false;
        return _this;
    }
    WebTabDescription.prototype.get_type = function () {
        return "WebTab";
    };
    Object.defineProperty(WebTabDescription.prototype, "type", {
        get: function () {
            return this.get_type();
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WebTabDescription.prototype, "label", {
        get: function () {
            return this.l;
        },
        set: function (a) {
            this.l = a;
            this.g("Label");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WebTabDescription.prototype, "selected", {
        get: function () {
            return this.i;
        },
        set: function (a) {
            this.i = a;
            this.g("Selected");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WebTabDescription.prototype, "disabled", {
        get: function () {
            return this.h;
        },
        set: function (a) {
            this.h = a;
            this.g("Disabled");
        },
        enumerable: false,
        configurable: true
    });
    WebTabDescription.$t = markType(WebTabDescription, 'WebTabDescription', Description.$);
    return WebTabDescription;
}(Description));
export { WebTabDescription };
